==> eiffelstudio-18.11.10.2592.tar: F_code/C69/re3424.c <==
/*
 * Code for class RESIZABLE [INTEGER_64]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "re3424.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {RESIZABLE}.additional_space */
EIF_INTEGER_32 F1325_14019 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R11908[Dtype(Current)-1350])(Current);
	Result = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
	RTLE;
	return Result;
}

/* {RESIZABLE}.automatic_grow */
void F1325_14021 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R11908[dtype-1350])(Current);
	{
		/* INLINED CODE (additional_space) */
		ti4_2 = (EIF_INTEGER_32)  0;
		ti4_3 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R11908[Dtype(Current)-1350])(Current);
		ti4_2 = eif_max_int32 ((EIF_INTEGER_32) (ti4_3 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
		/* END INLINED CODE */
	}
	ti4_3 = ti4_2;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R11914[dtype-1350])(Current, (EIF_INTEGER_32) (ti4_1 + ti4_3));
	RTLE;
}

void EIF_Minit3424 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C69/re3424.c <==
/*
 * Code for class RESIZABLE [NATURAL_16]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "re3424.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {RESIZABLE}.additional_space */
EIF_INTEGER_32 F1345_14093 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R11951[Dtype(Current)-1372])(Current);
	Result = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
	RTLE;
	return Result;
}

/* {RESIZABLE}.automatic_grow */
void F1345_14095 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R11951[dtype-1372])(Current);
	{
		/* INLINED CODE (RESIZABLE.additional_space) */
		ti4_2 = (EIF_INTEGER_32)  0;
		ti4_3 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R11951[Dtype(Current)-1372])(Current);
		ti4_2 = eif_max_int32 ((EIF_INTEGER_32) (ti4_3 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
		/* END INLINED CODE */
	}
	ti4_3 = ti4_2;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R11957[dtype-1372])(Current, (EIF_INTEGER_32) (ti4_1 + ti4_3));
	RTLE;
}

void EIF_Minit3424 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
